==> pochy-0.1.7-src.tar.gz: pochy-0.1.7-src/HeaderView.cpp <==
// HeaderView.cpp : Cve[V t@C
//

#include "stdafx.h"
#include "pochy.h"
#include "HeaderView.h"
#include "MainFrm.h"
#include "_regex.h"
#include "lib.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CHeaderView

IMPLEMENT_DYNCREATE(CHeaderView, CRichEditView)

CHeaderView::CHeaderView()
{
}

CHeaderView::~CHeaderView()
{
}


BEGIN_MESSAGE_MAP(CHeaderView, CRichEditView)
	//{{AFX_MSG_MAP(CHeaderView)
	ON_WM_CHAR()
	//}}AFX_MSG_MAP
	ON_NOTIFY_REFLECT_EX(EN_LINK, OnLink)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CHeaderView `

void CHeaderView::OnDraw(CDC* pDC)
{
	CDocument* pDoc = GetDocument();
	// TODO: ̈ʒuɕ`p̃R[hǉĂ
}

/////////////////////////////////////////////////////////////////////////////
// CHeaderView ff

#ifdef _DEBUG
void CHeaderView::AssertValid() const
{
	CRichEditView::AssertValid();
}

void CHeaderView::Dump(CDumpContext& dc) const
{
	CRichEditView::Dump(dc);
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CHeaderView bZ[W nh

void CHeaderView::OnInitialUpdate() 
{
	CRichEditView::OnInitialUpdate();
	CPochyApp *app = (CPochyApp *)AfxGetApp();
	
	this->GetRichEditCtrl().SetReadOnly();
	COLORREF cr = GetSysColor(COLOR_BTNFACE);
	this->GetRichEditCtrl().SetBackgroundColor(FALSE, cr);

	LOGFONT lf;
	LPBYTE pData;
	UINT nSize;
	if(app->GetProfileBinary("HeaderViewFont", "LogFont", &pData, &nSize)){
		ASSERT(nSize == sizeof(LOGFONT));
		::CopyMemory(&lf, pData, sizeof(LOGFONT));
		delete [] pData;
	}else{
		lf.lfHeight = -12;
		lf.lfWidth = 0;
		lf.lfEscapement = 0;
		lf.lfOrientation = 0;
		lf.lfWeight = 400;
		lf.lfItalic = 0;
		lf.lfUnderline = 0;
		lf.lfStrikeOut = 0;
		lf.lfCharSet = 128;
		lf.lfOutPrecision = 3;
		lf.lfClipPrecision = 2;
		lf.lfQuality = 1;
		lf.lfPitchAndFamily = 49;
		strcpy(lf.lfFaceName, "lr SVbN");
	}
	this->SetFontEx(lf);

	::SendMessage(m_hWnd, EM_AUTOURLDETECT, TRUE, 0);
	this->GetRichEditCtrl().SetEventMask(ENM_LINK);

}

BOOL CHeaderView::PreCreateWindow(CREATESTRUCT& cs) 
{
	BOOL b = CRichEditView::PreCreateWindow(cs);
	cs.style &= ~(WS_HSCROLL);
	return b;
}

void CHeaderView::Clear()
{
	this->GetRichEditCtrl().SetWindowText(_T(""));
}

void CHeaderView::SetFontEx(LOGFONT &lf)
{
	m_font.DeleteObject();
	if(m_font.CreateFontIndirect(&lf))
		GetRichEditCtrl().SetFont(&m_font);
}

void CHeaderView::SetHeaderText(CString buf)
{
	int len = 0;
	
	this->SetWindowText(_T(""));
	this->SetWindowText(buf);

	regex_t reg;
	regmatch_t pmatch[2]; 
	CString regex = "[a-z0-9\.\_\-]+@[a-z0-9\.\_\-]+";
	regcomp(&reg, regex, REG_EXTENDED | REG_NEWLINE | REG_ICASE);

	CHARFORMAT2 cf;
	this->GetRichEditCtrl().GetSelectionCharFormat(cf);
	cf.dwMask = CFM_LINK;
	cf.dwEffects = CFE_LINK;

	while(buf.GetLength() > 0){
		if(!regexec(&reg, buf, 2, pmatch, 0)){
			this->GetRichEditCtrl().SetSel(len+pmatch[0].rm_so, len+pmatch[0].rm_eo);
			this->GetRichEditCtrl().SetSelectionCharFormat(cf);
			this->GetRichEditCtrl().HideSelection(TRUE, FALSE);
			this->GetRichEditCtrl().SetSel(0, 0);
			len += pmatch[0].rm_eo+1;
			buf = buf.Mid(pmatch[0].rm_eo+1);
		}else{
			break;
		}
	}
	regfree(&reg);
}

void CHeaderView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
{
	CPochyApp *app = (CPochyApp *)AfxGetApp();
	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
	CString current_account = mf->m_pAcntV->GetCurrentAccountName();

	ENLINK * pLink = (ENLINK*)in_pNotifyHeader;
	if(pLink->msg == WM_LBUTTONDBLCLK && m_onlink != pLink->lParam){
		m_onlink = pLink->lParam;

		this->GetRichEditCtrl().SetSel(pLink->chrg);
		CString link = this->GetRichEditCtrl().GetSelText();

		// initialization.
		app->m_me.Initialize();
		// setting To
		app->m_me.SetTo(link);
		// setting From
		CString path = app->m_app_path+"\\"+current_account+"\\account.ini";
		CString address;
		GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
		address.ReleaseBuffer();
		app->m_me.SetFrom(address);
		// getting signature.
		CString signature;
		g_file2cstring(app->m_app_path+"\\"+current_account+"\\signature", signature);
		// set main text.
		app->m_me.AddText(signature);
		// draftframe
		app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
	}else if(pLink->msg == WM_RBUTTONDOWN){

	}
}

void CHeaderView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
{
	CPochyApp *app = (CPochyApp *)AfxGetApp();
	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;

	if(mf->Char(nChar))
		return;
	
	CRichEditView::OnChar(nChar, nRepCnt, nFlags);
}

==> pochy-0.1.8-src.tar.gz: pochy-0.1.8-src/HeaderView.cpp <==
// HeaderView.cpp : Cve[V t@C
//

#include "stdafx.h"
#include "pochy.h"
#include "HeaderView.h"
#include "MainFrm.h"
#include "_regex.h"
#include "lib.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

#define HEADERVIEW_BACKGROUND_FILENAME _T("\\skin\\HeaderViewBk.bmp")

/////////////////////////////////////////////////////////////////////////////
// CHeaderView

IMPLEMENT_DYNCREATE(CHeaderView, CRichEditView)

CHeaderView::CHeaderView()
{
}

CHeaderView::~CHeaderView()
{
}


BEGIN_MESSAGE_MAP(CHeaderView, CBitmapRichEditView)
	//{{AFX_MSG_MAP(CHeaderView)
	ON_WM_CHAR()
	//}}AFX_MSG_MAP
	ON_NOTIFY_REFLECT_EX(EN_LINK, OnLink)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CHeaderView `

void CHeaderView::OnDraw(CDC* pDC)
{
	CDocument* pDoc = GetDocument();
	// TODO: ̈ʒuɕ`p̃R[hǉĂ
}

/////////////////////////////////////////////////////////////////////////////
// CHeaderView ff

#ifdef _DEBUG
void CHeaderView::AssertValid() const
{
	CRichEditView::AssertValid();
}

void CHeaderView::Dump(CDumpContext& dc) const
{
	CRichEditView::Dump(dc);
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CHeaderView bZ[W nh

void CHeaderView::OnInitialUpdate() 
{
	CRichEditView::OnInitialUpdate();
	CPochyApp *app = (CPochyApp *)AfxGetApp();
	
	this->GetRichEditCtrl().SetReadOnly();
	COLORREF cr = GetSysColor(COLOR_BTNFACE);
	this->GetRichEditCtrl().SetBackgroundColor(FALSE, cr);
	this->GetRichEditCtrl().SetBackgroundColor(FALSE, RGB(
				app->GetProfileInt("HeaderViewColor", "BkColorR", GetRValue(cr)),
				app->GetProfileInt("HeaderViewColor", "BkColorG", GetGValue(cr)),
				app->GetProfileInt("HeaderViewColor", "BkColorB", GetBValue(cr))));

	

	LOGFONT lf;
	LPBYTE pData;
	UINT nSize;
	if(app->GetProfileBinary("HeaderViewFont", "LogFont", &pData, &nSize)){
		ASSERT(nSize == sizeof(LOGFONT));
		::CopyMemory(&lf, pData, sizeof(LOGFONT));
		delete [] pData;
	}else{
		lf.lfHeight = -12;
		lf.lfWidth = 0;
		lf.lfEscapement = 0;
		lf.lfOrientation = 0;
		lf.lfWeight = 400;
		lf.lfItalic = 0;
		lf.lfUnderline = 0;
		lf.lfStrikeOut = 0;
		lf.lfCharSet = 128;
		lf.lfOutPrecision = 3;
		lf.lfClipPrecision = 2;
		lf.lfQuality = 1;
		lf.lfPitchAndFamily = 49;
		strcpy(lf.lfFaceName, "lr SVbN");
	}
	this->SetFontEx(lf);

	::SendMessage(m_hWnd, EM_AUTOURLDETECT, TRUE, 0);
	this->GetRichEditCtrl().SetEventMask(ENM_LINK);

	// wb_[r[̔wi摜ݒ
	CString strBackgroundFilePath;
	if(app->m_skin.getHeaderViewBackBmp() == ""){
		strBackgroundFilePath = app->m_app_path + HEADERVIEW_BACKGROUND_FILENAME;
	}else{
		strBackgroundFilePath = app->m_skin.getSkinIniPath() + "\\" + app->m_skin.getHeaderViewBackBmp();
	}
	SetBkImage(strBackgroundFilePath);
//	CString strBackgroundFilePath = app->m_app_path + HEADERVIEW_BACKGROUND_FILENAME;
//	SetBkImage(strBackgroundFilePath);
}

BOOL CHeaderView::PreCreateWindow(CREATESTRUCT& cs) 
{
	BOOL b = CBitmapRichEditView::PreCreateWindow(cs);
	cs.style &= ~(WS_HSCROLL);
	return b;
}

void CHeaderView::Clear()
{
	this->GetRichEditCtrl().SetWindowText(_T(""));
}

void CHeaderView::SetFontEx(LOGFONT &lf)
{
	m_font.DeleteObject();
	if(m_font.CreateFontIndirect(&lf))
		GetRichEditCtrl().SetFont(&m_font);
}

void CHeaderView::SetHeaderText(CString buf)
{
	int len = 0;
	int start, end;
	CString buf2, tmp1, tmp2;
	buf2 = buf;
	
	this->SetWindowText(_T(""));
	this->SetWindowText(buf);

	regex_t reg;
	regmatch_t pmatch[2]; 
	CString regex = "[a-z0-9\.\_\-]+@[a-z0-9\.\_\-]+";
	regcomp(&reg, regex, REG_EXTENDED | REG_NEWLINE | REG_ICASE);

	CHARFORMAT2 cf;
	this->GetRichEditCtrl().GetSelectionCharFormat(cf);
	cf.dwMask = CFM_LINK;
	cf.dwEffects = CFE_LINK;

	while(buf.GetLength() > 0){
		if(!regexec(&reg, buf2, 2, pmatch, 0)){
			start = g_richedit_count_char(buf.Left(len+pmatch[0].rm_so));
			end = g_richedit_count_char(buf.Left(len+pmatch[0].rm_eo));
			this->GetRichEditCtrl().SetSel(start, end);
			this->GetRichEditCtrl().SetSelectionCharFormat(cf);
			this->GetRichEditCtrl().HideSelection(TRUE, FALSE);
			this->GetRichEditCtrl().SetSel(0, 0);
			len += pmatch[0].rm_eo+1;
			buf2 = buf2.Mid(pmatch[0].rm_eo+1);
		}else{
			break;
		}
	}
	regfree(&reg);
}

void CHeaderView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
{
	CPochyApp *app = (CPochyApp *)AfxGetApp();
	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
	CString current_account = mf->m_pAcntV->GetCurrentAccountName();

	ENLINK * pLink = (ENLINK*)in_pNotifyHeader;
	if(pLink->msg == WM_LBUTTONDBLCLK && m_onlink != pLink->lParam){
		m_onlink = pLink->lParam;

		this->GetRichEditCtrl().SetSel(pLink->chrg);
		CString link = this->GetRichEditCtrl().GetSelText();

		// initialization.
		app->m_me.Initialize();
		// setting To
		app->m_me.SetTo(link);
		// setting From
		CString path = app->m_app_path+"\\"+current_account+"\\account.ini";
		CString address;
		GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
		address.ReleaseBuffer();
		app->m_me.SetFrom(address);
		// getting signature.
		CString signature;
		g_file2cstring(app->m_app_path+"\\"+current_account+"\\signature", signature);
		// set main text.
		app->m_me.AddText(signature);
		// draftframe
		app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
	}else if(pLink->msg == WM_RBUTTONDOWN){

	}
}

void CHeaderView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
{
	CPochyApp *app = (CPochyApp *)AfxGetApp();
	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;

	if(mf->Char(nChar))
		return;
	
	CRichEditView::OnChar(nChar, nRepCnt, nFlags);
}
